# Audiostems

Audio STEM Separation powered by [Spleeter](https://pypi.org/project/spleeter/)

Download Youtube Audio to WAV and Separate Stems 


### What is a stem? 

Stems are the different components that make up a music, in most cases you have vocals, drums, bass, and other instrumentation. According to the current scientific status, there will never be an algorithm that restores the exact master tracks before mixing, but with machine learning some people have developed some methods for estimation. There are different approaches largely depending on how much spare time you have on your hands. 

1. Method: Train your own neural network & Build your own database: Not possible unless you have a lot of experience and a lot of work. (Use work synonomous for time because time and space are connected)

2. Method: Train your own network with someone else's dataset, possible good results require a lot of experience + work

3. Method: Use someone else's pretrained network, that is what the Audiostems Project is, It depends on the Spleeter Network developed by a team at deezer.com 

4. Method: Use someone else's shitty website that requires you to login to process a reasonable amount of data. 

As you can see the goal of this Project is to provide creative minds with the right tools. This is more like a toolbox. 


